@@ -1,3 +1,3 @@
 __all__ = ["base_graph", "base_transform", "bond", "extrastats", "generator", "envir",
-           "atom", "bond", "descriptors", "state",
+           "atom", "bond", "descriptors", "state", "base_graph_geo", "batch_feature"
            ]
